from pydantic import BaseModel


class ListParams(BaseModel):
    url: str = "/Ajax/controlerAjaxModule.php"
    type: str = "KwaooCrm"
    request: str
    link: int
    itemNumberByPage: int = 100
    order: str = "lastUpdate"
    typeOrder: str = "desc"
    page: int = 1
    search: str = ""
    status_column: int | None = None
    id_column: int = 0


class KNetListParams(ListParams):
    request: str = "getKnetCustomerListList"
    knetStatusFilter: str = ""
    knetOfferFilter: str = ""
    knetDspFilter: str = ""
    link: int = 35747
    status_column: int | None = 3


class KNetProListParams(ListParams):
    request: str = "getKnetProCustomerManagerList"
    knetProStatusFilter: str = ""
    knetProTagFilter: str = ""
    knetProDspFilter: str = ""
    link: int = 35748
    status_column: int | None = 4
    id_column: int = 1


class KNetProContactListParams(ListParams):
    request: str = "getContactKnetProListList"
    order: str = "firstName"
    typeOrder: str = "asc"
    link: int = 35787


class StellaListParams(ListParams):
    request: str = "getStellaCustomerManagerList"
    stellaStatusFilter: str = ""
    link: int = 35749
    status_column: int | None = 3


class KSysListParams(ListParams):
    request: str = "getKsysCustomerListList"
    ksysStatusFilter: str = ""
    link: int = 35756
    status_column: int | None = 3


record_types: dict[str, ListParams] = {
    "knet_gp": KNetListParams(),
    "knet_pro": KNetProListParams(),
    # "Contacts K-net pro": KNetProContactListParams(),
    "stella": StellaListParams(),
    "ksys": KSysListParams(),
}


class MiweoIdRecord(BaseModel):
    id: str
    link: str


class ListItem(BaseModel):
    id: str
    status: str | None


class List(BaseModel):
    length: int
    items: list[ListItem]
